{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-one" => "'selmana' W 'de' MMMM",
    "MMMMW-count-other" => "'selmana' W 'de' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "LLLL 'de' y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ 'de' y",
    "yw-count-one" => "'selmana' w 'de' Y",
    "yw-count-other" => "'selmana' w 'de' Y",
  },
  code => "ast",
  date_format_full => "EEEE, d MMMM 'de' y",
  date_format_long => "d MMMM 'de' y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "llu",
    "mar",
    "mi\N{U+00e9}",
    "xue",
    "vie",
    "s\N{U+00e1}b",
    "dom",
  ],
  day_format_narrow => [
    "L",
    "M",
    "M",
    "X",
    "V",
    "S",
    "D",
  ],
  day_format_wide => [
    "llunes",
    "martes",
    "mi\N{U+00e9}rcoles",
    "xueves",
    "vienres",
    "s\N{U+00e1}badu",
    "domingu",
  ],
  day_stand_alone_abbreviated => [
    "llu",
    "mar",
    "mi\N{U+00e9}",
    "xue",
    "vie",
    "s\N{U+00e1}b",
    "dom",
  ],
  day_stand_alone_narrow => [
    "L",
    "M",
    "M",
    "X",
    "V",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "llunes",
    "martes",
    "mi\N{U+00e9}rcoles",
    "xueves",
    "vienres",
    "s\N{U+00e1}badu",
    "domingu",
  ],
  era_abbreviated => [
    "e.C.",
    "d.C.",
  ],
  era_narrow => [
    "e.C.",
    "d.C.",
  ],
  era_wide => [
    "enantes de Cristu",
    "despu\N{U+00e9}s de Cristu",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Asturian",
  month_format_abbreviated => [
    "xin",
    "feb",
    "mar",
    "abr",
    "may",
    "xun",
    "xnt",
    "ago",
    "set",
    "och",
    "pay",
    "avi",
  ],
  month_format_narrow => [
    "X",
    "F",
    "M",
    "A",
    "M",
    "X",
    "X",
    "A",
    "S",
    "O",
    "P",
    "A",
  ],
  month_format_wide => [
    "de xineru",
    "de febreru",
    "de marzu",
    "d\N{U+2019}abril",
    "de mayu",
    "de xunu",
    "de xunetu",
    "d\N{U+2019}agostu",
    "de setiembre",
    "d\N{U+2019}ochobre",
    "de payares",
    "d\N{U+2019}avientu",
  ],
  month_stand_alone_abbreviated => [
    "Xin",
    "Feb",
    "Mar",
    "Abr",
    "May",
    "Xun",
    "Xnt",
    "Ago",
    "Set",
    "Och",
    "Pay",
    "Avi",
  ],
  month_stand_alone_narrow => [
    "X",
    "F",
    "M",
    "A",
    "M",
    "X",
    "X",
    "A",
    "S",
    "O",
    "P",
    "A",
  ],
  month_stand_alone_wide => [
    "xineru",
    "febreru",
    "marzu",
    "abril",
    "mayu",
    "xunu",
    "xunetu",
    "agostu",
    "setiembre",
    "ochobre",
    "payares",
    "avientu",
  ],
  name => "Asturian",
  native_language => "asturianu",
  native_name => "asturianu",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "1T",
    "2T",
    "3T",
    "4T",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1er trimestre",
    "2u trimestre",
    "3er trimestre",
    "4u trimestre",
  ],
  quarter_stand_alone_abbreviated => [
    "1T",
    "2T",
    "3T",
    "4T",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1er trimestre",
    "2u trimestre",
    "3er trimestre",
    "4u trimestre",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
