{
  am_pm_abbreviated => [
    "n\N{U+202f}tufat",
    "n\N{U+202f}tmeddit",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "M",
    MEd => "MM-dd, E",
    MMM => "MMM",
    MMMEd => "E d MMM",
    MMMMEd => "E d MMMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMd => "d/MM",
    MMdd => "dd/MM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMM => "MM/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "kab-DZ",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "San",
    "Kra\N{U+1e0d}",
    "Ku\N{U+1e93}",
    "Sam",
    "S\N{U+1e0d}is",
    "Say",
    "Yan",
  ],
  day_format_narrow => [
    "S",
    "K",
    "K",
    "S",
    "S",
    "S",
    "Y",
  ],
  day_format_wide => [
    "Sanass",
    "Kra\N{U+1e0d}ass",
    "Ku\N{U+1e93}ass",
    "Samass",
    "S\N{U+1e0d}isass",
    "Sayass",
    "Yanass",
  ],
  day_stand_alone_abbreviated => [
    "San",
    "Kra\N{U+1e0d}",
    "Ku\N{U+1e93}",
    "Sam",
    "S\N{U+1e0d}is",
    "Say",
    "Yan",
  ],
  day_stand_alone_narrow => [
    "S",
    "K",
    "K",
    "S",
    "S",
    "S",
    "Y",
  ],
  day_stand_alone_wide => [
    "Sanass",
    "Kra\N{U+1e0d}ass",
    "Ku\N{U+1e93}ass",
    "Samass",
    "S\N{U+1e0d}isass",
    "Sayass",
    "Yanass",
  ],
  era_abbreviated => [
    "snd. T.\N{U+0190}",
    "sld. T.\N{U+0190}",
  ],
  era_narrow => [
    "snd. T.\N{U+0190}",
    "sld. T.\N{U+0190}",
  ],
  era_wide => [
    "send talalit n \N{U+0190}isa",
    "seld talalit n \N{U+0190}isa",
  ],
  first_day_of_week => 6,
  glibc_date_1_format => "%a %d %b %Y %T %Z",
  glibc_date_format => "%d/%m/%Y",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Kabyle",
  month_format_abbreviated => [
    "Yen",
    "Fur",
    "Me\N{U+0263}",
    "Yeb",
    "May",
    "Yun",
    "Yul",
    "\N{U+0194}uc",
    "Cte",
    "Tub",
    "Nun",
    "Du\N{U+01e7}",
  ],
  month_format_narrow => [
    "Y",
    "F",
    "M",
    "Y",
    "M",
    "Y",
    "Y",
    "\N{U+0194}",
    "C",
    "T",
    "N",
    "D",
  ],
  month_format_wide => [
    "Yennayer",
    "Fu\N{U+1e5b}ar",
    "Me\N{U+0263}res",
    "Yebrir",
    "Mayyu",
    "Yunyu",
    "Yulyu",
    "\N{U+0194}uct",
    "Ctembe\N{U+1e5b}",
    "Tube\N{U+1e5b}",
    "Nunembe\N{U+1e5b}",
    "Du\N{U+01e7}embe\N{U+1e5b}",
  ],
  month_stand_alone_abbreviated => [
    "Yen",
    "Fur",
    "Me\N{U+0263}",
    "Yeb",
    "May",
    "Yun",
    "Yul",
    "\N{U+0194}uc",
    "Cte",
    "Tub",
    "Nun",
    "Du\N{U+01e7}",
  ],
  month_stand_alone_narrow => [
    "Y",
    "F",
    "M",
    "Y",
    "M",
    "Y",
    "Y",
    "\N{U+0194}",
    "C",
    "T",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Yennayer",
    "Fu\N{U+1e5b}ar",
    "Me\N{U+0263}res",
    "Yebrir",
    "Mayyu",
    "Yunyu",
    "Yulyu",
    "\N{U+0194}uct",
    "Ctembe\N{U+1e5b}",
    "Tube\N{U+1e5b}",
    "Nunembe\N{U+1e5b}",
    "Du\N{U+01e7}embe\N{U+1e5b}",
  ],
  name => "Kabyle Algeria",
  native_language => "Taqbaylit",
  native_name => "Taqbaylit Lezzayer",
  native_script => undef,
  native_territory => "Lezzayer",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K\N{U+1e0d}g1",
    "K\N{U+1e0d}g2",
    "K\N{U+1e0d}g3",
    "K\N{U+1e0d}g4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "akra\N{U+1e0d}aggur amenzu",
    "akra\N{U+1e0d}aggur wis-sin",
    "akra\N{U+1e0d}aggur wis-kra\N{U+1e0d}",
    "akra\N{U+1e0d}aggur wis-ku\N{U+1e93}",
  ],
  quarter_stand_alone_abbreviated => [
    "K\N{U+1e0d}g1",
    "K\N{U+1e0d}g2",
    "K\N{U+1e0d}g3",
    "K\N{U+1e0d}g4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "akra\N{U+1e0d}aggur amenzu",
    "akra\N{U+1e0d}aggur wis-sin",
    "akra\N{U+1e0d}aggur wis-kra\N{U+1e0d}",
    "akra\N{U+1e0d}aggur wis-ku\N{U+1e93}",
  ],
  script => undef,
  territory => "Algeria",
  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
  time_format_long => "h:mm:ss\N{U+202f}a z",
  time_format_medium => "h:mm:ss\N{U+202f}a",
  time_format_short => "h:mm\N{U+202f}a",
  variant => undef,
  version => 42,
}
