{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "dd MM y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    MMMMEd => "E d MMMM",
    "MMMMW-count-other" => "'uike' 'hono' W \N{U+02bb}'o' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMM => "MM-y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'uike' 'hono' w \N{U+02bb}'o' Y",
  },
  code => "to",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "M\N{U+014d}n",
    "T\N{U+016b}s",
    "Pul",
    "Tu\N{U+02bb}a",
    "Fal",
    "Tok",
    "S\N{U+0101}p",
  ],
  day_format_narrow => [
    "M",
    "T",
    "P",
    "T",
    "F",
    "T",
    "S",
  ],
  day_format_wide => [
    "M\N{U+014d}nite",
    "T\N{U+016b}site",
    "Pulelulu",
    "Tu\N{U+02bb}apulelulu",
    "Falaite",
    "Tokonaki",
    "S\N{U+0101}pate",
  ],
  day_stand_alone_abbreviated => [
    "M\N{U+014d}n",
    "T\N{U+016b}s",
    "Pul",
    "Tu\N{U+02bb}a",
    "Fal",
    "Tok",
    "S\N{U+0101}p",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "P",
    "T",
    "F",
    "T",
    "S",
  ],
  day_stand_alone_wide => [
    "M\N{U+014d}nite",
    "T\N{U+016b}site",
    "Pulelulu",
    "Tu\N{U+02bb}apulelulu",
    "Falaite",
    "Tokonaki",
    "S\N{U+0101}pate",
  ],
  era_abbreviated => [
    "KM",
    "TS",
  ],
  era_narrow => [
    "KM",
    "TS",
  ],
  era_wide => [
    "ki mu\N{U+02bb}a",
    "ta\N{U+02bb}u \N{U+02bb}o S\N{U+012b}s\N{U+016b}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Tongan",
  month_format_abbreviated => [
    "S\N{U+0101}n",
    "F\N{U+0113}p",
    "Ma\N{U+02bb}a",
    "\N{U+02bb}Epe",
    "M\N{U+0113}",
    "Sun",
    "Siu",
    "\N{U+02bb}Aok",
    "Sep",
    "\N{U+02bb}Oka",
    "N\N{U+014d}v",
    "T\N{U+012b}s",
  ],
  month_format_narrow => [
    "S",
    "F",
    "M",
    "\N{U+02bb}E",
    "M",
    "S",
    "S",
    "\N{U+02bb}A",
    "S",
    "\N{U+02bb}O",
    "N",
    "T",
  ],
  month_format_wide => [
    "S\N{U+0101}nuali",
    "F\N{U+0113}pueli",
    "Ma\N{U+02bb}asi",
    "\N{U+02bb}Epeleli",
    "M\N{U+0113}",
    "Sune",
    "Siulai",
    "\N{U+02bb}Aokosi",
    "Sepitema",
    "\N{U+02bb}Okatopa",
    "N\N{U+014d}vema",
    "T\N{U+012b}sema",
  ],
  month_stand_alone_abbreviated => [
    "S\N{U+0101}n",
    "F\N{U+0113}p",
    "Ma\N{U+02bb}a",
    "\N{U+02bb}Epe",
    "M\N{U+0113}",
    "Sun",
    "Siu",
    "\N{U+02bb}Aok",
    "Sep",
    "\N{U+02bb}Oka",
    "N\N{U+014d}v",
    "T\N{U+012b}s",
  ],
  month_stand_alone_narrow => [
    "S",
    "F",
    "M",
    "E",
    "M",
    "S",
    "S",
    "A",
    "S",
    "O",
    "N",
    "T",
  ],
  month_stand_alone_wide => [
    "S\N{U+0101}nuali",
    "F\N{U+0113}pueli",
    "Ma\N{U+02bb}asi",
    "\N{U+02bb}Epeleli",
    "M\N{U+0113}",
    "Sune",
    "Siulai",
    "\N{U+02bb}Aokosi",
    "Sepitema",
    "\N{U+02bb}Okatopa",
    "N\N{U+014d}vema",
    "T\N{U+012b}sema",
  ],
  name => "Tongan",
  native_language => "lea fakatonga",
  native_name => "lea fakatonga",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "kuata \N{U+02bb}uluaki",
    "kuata ua",
    "kuata tolu",
    "kuata f\N{U+0101}",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "kuata 1",
    "kuata 2",
    "kuata 3",
    "kuata 4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
  time_format_long => "h:mm:ss\N{U+202f}a z",
  time_format_medium => "h:mm:ss\N{U+202f}a",
  time_format_short => "h:mm\N{U+202f}a",
  variant => undef,
  version => 42,
}
