{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E dd/MM",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "dd/MM",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM y",
    yMEd => "E dd/MM y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "dd/MM y",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "kkj",
  date_format_full => "EEEE dd MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "lundi",
    "mardi",
    "m\N{U+025b}rk\N{U+025b}r\N{U+025b}di",
    "yedi",
    "va\N{U+014b}d\N{U+025b}r\N{U+025b}di",
    "m\N{U+0254}n\N{U+0254} s\N{U+0254}ndi",
    "s\N{U+0254}ndi",
  ],
  day_format_narrow => [
    "lu",
    "ma",
    "m\N{U+025b}",
    "ye",
    "va",
    "ms",
    "so",
  ],
  day_format_wide => [
    "lundi",
    "mardi",
    "m\N{U+025b}rk\N{U+025b}r\N{U+025b}di",
    "yedi",
    "va\N{U+014b}d\N{U+025b}r\N{U+025b}di",
    "m\N{U+0254}n\N{U+0254} s\N{U+0254}ndi",
    "s\N{U+0254}ndi",
  ],
  day_stand_alone_abbreviated => [
    "lundi",
    "mardi",
    "m\N{U+025b}rk\N{U+025b}r\N{U+025b}di",
    "yedi",
    "va\N{U+014b}d\N{U+025b}r\N{U+025b}di",
    "m\N{U+0254}n\N{U+0254} s\N{U+0254}ndi",
    "s\N{U+0254}ndi",
  ],
  day_stand_alone_narrow => [
    "lu",
    "ma",
    "m\N{U+025b}",
    "ye",
    "va",
    "ms",
    "so",
  ],
  day_stand_alone_wide => [
    "lundi",
    "mardi",
    "m\N{U+025b}rk\N{U+025b}r\N{U+025b}di",
    "yedi",
    "va\N{U+014b}d\N{U+025b}r\N{U+025b}di",
    "m\N{U+0254}n\N{U+0254} s\N{U+0254}ndi",
    "s\N{U+0254}ndi",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "BCE",
    "CE",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Kako",
  month_format_abbreviated => [
    "pamba",
    "wanja",
    "mbiy\N{U+0254} m\N{U+025b}ndo\N{U+014b}g\N{U+0254}",
    "Ny\N{U+0254}l\N{U+0254}mb\N{U+0254}\N{U+014b}g\N{U+0254}",
    "M\N{U+0254}n\N{U+0254} \N{U+014b}gbanja",
    "Nya\N{U+014b}gw\N{U+025b} \N{U+014b}gbanja",
    "ku\N{U+014b}gw\N{U+025b}",
    "f\N{U+025b}",
    "njapi",
    "nyukul",
    "M11",
    "\N{U+0253}ul\N{U+0253}us\N{U+025b}",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "pamba",
    "wanja",
    "mbiy\N{U+0254} m\N{U+025b}ndo\N{U+014b}g\N{U+0254}",
    "Ny\N{U+0254}l\N{U+0254}mb\N{U+0254}\N{U+014b}g\N{U+0254}",
    "M\N{U+0254}n\N{U+0254} \N{U+014b}gbanja",
    "Nya\N{U+014b}gw\N{U+025b} \N{U+014b}gbanja",
    "ku\N{U+014b}gw\N{U+025b}",
    "f\N{U+025b}",
    "njapi",
    "nyukul",
    "M11",
    "\N{U+0253}ul\N{U+0253}us\N{U+025b}",
  ],
  month_stand_alone_abbreviated => [
    "pamba",
    "wanja",
    "mbiy\N{U+0254} m\N{U+025b}ndo\N{U+014b}g\N{U+0254}",
    "Ny\N{U+0254}l\N{U+0254}mb\N{U+0254}\N{U+014b}g\N{U+0254}",
    "M\N{U+0254}n\N{U+0254} \N{U+014b}gbanja",
    "Nya\N{U+014b}gw\N{U+025b} \N{U+014b}gbanja",
    "ku\N{U+014b}gw\N{U+025b}",
    "f\N{U+025b}",
    "njapi",
    "nyukul",
    "M11",
    "\N{U+0253}ul\N{U+0253}us\N{U+025b}",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "pamba",
    "wanja",
    "mbiy\N{U+0254} m\N{U+025b}ndo\N{U+014b}g\N{U+0254}",
    "Ny\N{U+0254}l\N{U+0254}mb\N{U+0254}\N{U+014b}g\N{U+0254}",
    "M\N{U+0254}n\N{U+0254} \N{U+014b}gbanja",
    "Nya\N{U+014b}gw\N{U+025b} \N{U+014b}gbanja",
    "ku\N{U+014b}gw\N{U+025b}",
    "f\N{U+025b}",
    "njapi",
    "nyukul",
    "M11",
    "\N{U+0253}ul\N{U+0253}us\N{U+025b}",
  ],
  name => "Kako",
  native_language => "kak\N{U+0254}",
  native_name => "kak\N{U+0254}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
