{
  am_pm_abbreviated => [
    "dop.",
    "pop.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E, d.",
    Ehm => "E, h:mm\N{U+202f}a",
    Ehms => "E, h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyM => "MMM y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d. MMM y G",
    GyMMMd => "d. MMM y G",
    GyMd => "d. M. y GGGGG",
    H => "HH'h'",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d. M.",
    MMM => "LLL",
    MMMEd => "E, d. MMM",
    "MMMMW-count-few" => "MMMM: W. 'teden'",
    "MMMMW-count-one" => "MMMM: W. 'teden'",
    "MMMMW-count-other" => "MMMM: W. 'teden'",
    "MMMMW-count-two" => "MMMM: W. 'teden'",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    Md => "d. M.",
    d => "d.",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d. M. y",
    yMMM => "MMM y",
    yMMMEd => "E, d. MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d. MMM y",
    yMd => "d. M. y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-few" => "w. 'teden' 'leta' Y",
    "yw-count-one" => "w. 'teden' 'leta' Y",
    "yw-count-other" => "w. 'teden' 'leta' Y",
    "yw-count-two" => "w. 'teden' 'leta' Y",
  },
  code => "sl-SI",
  date_format_full => "EEEE, d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d. MMM y",
  date_format_short => "d. MM. yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "pon.",
    "tor.",
    "sre.",
    "\N{U+010d}et.",
    "pet.",
    "sob.",
    "ned.",
  ],
  day_format_narrow => [
    "p",
    "t",
    "s",
    "\N{U+010d}",
    "p",
    "s",
    "n",
  ],
  day_format_wide => [
    "ponedeljek",
    "torek",
    "sreda",
    "\N{U+010d}etrtek",
    "petek",
    "sobota",
    "nedelja",
  ],
  day_stand_alone_abbreviated => [
    "pon.",
    "tor.",
    "sre.",
    "\N{U+010d}et.",
    "pet.",
    "sob.",
    "ned.",
  ],
  day_stand_alone_narrow => [
    "p",
    "t",
    "s",
    "\N{U+010d}",
    "p",
    "s",
    "n",
  ],
  day_stand_alone_wide => [
    "ponedeljek",
    "torek",
    "sreda",
    "\N{U+010d}etrtek",
    "petek",
    "sobota",
    "nedelja",
  ],
  era_abbreviated => [
    "pr. Kr.",
    "po Kr.",
  ],
  era_narrow => [
    "pr. Kr.",
    "po Kr.",
  ],
  era_wide => [
    "pred Kristusom",
    "po Kristusu",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %d %b %Y %T %Z",
  glibc_date_format => "%d. %m. %Y",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Slovenian",
  month_format_abbreviated => [
    "jan.",
    "feb.",
    "mar.",
    "apr.",
    "maj",
    "jun.",
    "jul.",
    "avg.",
    "sep.",
    "okt.",
    "nov.",
    "dec.",
  ],
  month_format_narrow => [
    "j",
    "f",
    "m",
    "a",
    "m",
    "j",
    "j",
    "a",
    "s",
    "o",
    "n",
    "d",
  ],
  month_format_wide => [
    "januar",
    "februar",
    "marec",
    "april",
    "maj",
    "junij",
    "julij",
    "avgust",
    "september",
    "oktober",
    "november",
    "december",
  ],
  month_stand_alone_abbreviated => [
    "jan.",
    "feb.",
    "mar.",
    "apr.",
    "maj",
    "jun.",
    "jul.",
    "avg.",
    "sep.",
    "okt.",
    "nov.",
    "dec.",
  ],
  month_stand_alone_narrow => [
    "j",
    "f",
    "m",
    "a",
    "m",
    "j",
    "j",
    "a",
    "s",
    "o",
    "n",
    "d",
  ],
  month_stand_alone_wide => [
    "januar",
    "februar",
    "marec",
    "april",
    "maj",
    "junij",
    "julij",
    "avgust",
    "september",
    "oktober",
    "november",
    "december",
  ],
  name => "Slovenian Slovenia",
  native_language => "sloven\N{U+0161}\N{U+010d}ina",
  native_name => "sloven\N{U+0161}\N{U+010d}ina Slovenija",
  native_script => undef,
  native_territory => "Slovenija",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1. \N{U+010d}et.",
    "2. \N{U+010d}et.",
    "3. \N{U+010d}et.",
    "4. \N{U+010d}et.",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. \N{U+010d}etrtletje",
    "2. \N{U+010d}etrtletje",
    "3. \N{U+010d}etrtletje",
    "4. \N{U+010d}etrtletje",
  ],
  quarter_stand_alone_abbreviated => [
    "1. \N{U+010d}et.",
    "2. \N{U+010d}et.",
    "3. \N{U+010d}et.",
    "4. \N{U+010d}et.",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. \N{U+010d}etrtletje",
    "2. \N{U+010d}etrtletje",
    "3. \N{U+010d}etrtletje",
    "4. \N{U+010d}etrtletje",
  ],
  script => undef,
  territory => "Slovenia",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
