{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E, d",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d. MMMM y G",
    GyMMMd => "d. MMM y G",
    GyMd => "d.MM.y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "M",
    MEd => "E, d.M",
    MMM => "MMMM",
    MMMEd => "E, d. MMM",
    MMMMEd => "E, d. MMMM",
    "MMMMW-count-one" => "MMMM (W. 'n\N{U+00e4}dal')",
    "MMMMW-count-other" => "MMMM (W. 'n\N{U+00e4}dal')",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    Md => "d.M",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y",
    yM => "M.y",
    yMEd => "E, d.M.y",
    yMMM => "MMM y",
    yMMMEd => "E, d. MMMM y",
    yMMMM => "MMMM y",
    yMMMd => "d. MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "w. 'n\N{U+00e4}dal' (Y)",
    "yw-count-other" => "w. 'n\N{U+00e4}dal' (Y)",
  },
  code => "et",
  date_format_full => "EEEE, d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d. MMM y",
  date_format_short => "dd.MM.yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "E",
    "T",
    "K",
    "N",
    "R",
    "L",
    "P",
  ],
  day_format_narrow => [
    "E",
    "T",
    "K",
    "N",
    "R",
    "L",
    "P",
  ],
  day_format_wide => [
    "esmasp\N{U+00e4}ev",
    "teisip\N{U+00e4}ev",
    "kolmap\N{U+00e4}ev",
    "neljap\N{U+00e4}ev",
    "reede",
    "laup\N{U+00e4}ev",
    "p\N{U+00fc}hap\N{U+00e4}ev",
  ],
  day_stand_alone_abbreviated => [
    "E",
    "T",
    "K",
    "N",
    "R",
    "L",
    "P",
  ],
  day_stand_alone_narrow => [
    "E",
    "T",
    "K",
    "N",
    "R",
    "L",
    "P",
  ],
  day_stand_alone_wide => [
    "esmasp\N{U+00e4}ev",
    "teisip\N{U+00e4}ev",
    "kolmap\N{U+00e4}ev",
    "neljap\N{U+00e4}ev",
    "reede",
    "laup\N{U+00e4}ev",
    "p\N{U+00fc}hap\N{U+00e4}ev",
  ],
  era_abbreviated => [
    "eKr",
    "pKr",
  ],
  era_narrow => [
    "eKr",
    "pKr",
  ],
  era_wide => [
    "enne Kristust",
    "p\N{U+00e4}rast Kristust",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Estonian",
  month_format_abbreviated => [
    "jaan",
    "veebr",
    "m\N{U+00e4}rts",
    "apr",
    "mai",
    "juuni",
    "juuli",
    "aug",
    "sept",
    "okt",
    "nov",
    "dets",
  ],
  month_format_narrow => [
    "J",
    "V",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "jaanuar",
    "veebruar",
    "m\N{U+00e4}rts",
    "aprill",
    "mai",
    "juuni",
    "juuli",
    "august",
    "september",
    "oktoober",
    "november",
    "detsember",
  ],
  month_stand_alone_abbreviated => [
    "jaan",
    "veebr",
    "m\N{U+00e4}rts",
    "apr",
    "mai",
    "juuni",
    "juuli",
    "aug",
    "sept",
    "okt",
    "nov",
    "dets",
  ],
  month_stand_alone_narrow => [
    "J",
    "V",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "jaanuar",
    "veebruar",
    "m\N{U+00e4}rts",
    "aprill",
    "mai",
    "juuni",
    "juuli",
    "august",
    "september",
    "oktoober",
    "november",
    "detsember",
  ],
  name => "Estonian",
  native_language => "eesti",
  native_name => "eesti",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. kvartal",
    "2. kvartal",
    "3. kvartal",
    "4. kvartal",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_stand_alone_wide => [
    "1. kvartal",
    "2. kvartal",
    "3. kvartal",
    "4. kvartal",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
