{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "B h",
    Bhm => "B h:mm",
    Bhms => "B h:mm:ss",
    E => "ccc",
    EBhm => "E B h:mm",
    EBhms => "E B h:mm:ss",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "G y",
    GyMMM => "G MMM y",
    GyMMMEd => "G d MMM y, E",
    GyMMMd => "G d MMM y",
    GyMd => "GGGGG d MMM y",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "dd.MM, E",
    MMM => "LLL",
    MMMEd => "d MMM, E",
    "MMMMW-count-one" => "MMMM, W 'h\N{U+0259}ft\N{U+0259}'",
    "MMMMW-count-other" => "MMMM, W 'h\N{U+0259}ft\N{U+0259}'",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "dd.MM",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM.y",
    yMEd => "dd.MM.y, E",
    yMMM => "MMM y",
    yMMMEd => "d MMM y, E",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "dd.MM.y",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-one" => "Y, w 'h\N{U+0259}ft\N{U+0259}'",
    "yw-count-other" => "Y, w 'h\N{U+0259}ft\N{U+0259}'",
  },
  code => "az-Latn-AZ",
  date_format_full => "d MMMM y, EEEE",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd.MM.yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "B.e.",
    "\N{U+00c7}.a.",
    "\N{U+00c7}.",
    "C.a.",
    "C.",
    "\N{U+015e}.",
    "B.",
  ],
  day_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
  ],
  day_format_wide => [
    "bazar ert\N{U+0259}si",
    "\N{U+00e7}\N{U+0259}r\N{U+015f}\N{U+0259}nb\N{U+0259} ax\N{U+015f}am\N{U+0131}",
    "\N{U+00e7}\N{U+0259}r\N{U+015f}\N{U+0259}nb\N{U+0259}",
    "c\N{U+00fc}m\N{U+0259} ax\N{U+015f}am\N{U+0131}",
    "c\N{U+00fc}m\N{U+0259}",
    "\N{U+015f}\N{U+0259}nb\N{U+0259}",
    "bazar",
  ],
  day_stand_alone_abbreviated => [
    "B.E.",
    "\N{U+00c7}.A.",
    "\N{U+00c7}.",
    "C.A.",
    "C.",
    "\N{U+015e}.",
    "B.",
  ],
  day_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
  ],
  day_stand_alone_wide => [
    "bazar ert\N{U+0259}si",
    "\N{U+00e7}\N{U+0259}r\N{U+015f}\N{U+0259}nb\N{U+0259} ax\N{U+015f}am\N{U+0131}",
    "\N{U+00e7}\N{U+0259}r\N{U+015f}\N{U+0259}nb\N{U+0259}",
    "c\N{U+00fc}m\N{U+0259} ax\N{U+015f}am\N{U+0131}",
    "c\N{U+00fc}m\N{U+0259}",
    "\N{U+015f}\N{U+0259}nb\N{U+0259}",
    "bazar",
  ],
  era_abbreviated => [
    "e.\N{U+0259}.",
    "y.e.",
  ],
  era_narrow => [
    "e.\N{U+0259}.",
    "y.e.",
  ],
  era_wide => [
    "eram\N{U+0131}zdan \N{U+0259}vv\N{U+0259}l",
    "yeni era",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Azerbaijani",
  month_format_abbreviated => [
    "yan",
    "fev",
    "mar",
    "apr",
    "may",
    "iyn",
    "iyl",
    "avq",
    "sen",
    "okt",
    "noy",
    "dek",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "yanvar",
    "fevral",
    "mart",
    "aprel",
    "may",
    "iyun",
    "iyul",
    "avqust",
    "sentyabr",
    "oktyabr",
    "noyabr",
    "dekabr",
  ],
  month_stand_alone_abbreviated => [
    "yan",
    "fev",
    "mar",
    "apr",
    "may",
    "iyn",
    "iyl",
    "avq",
    "sen",
    "okt",
    "noy",
    "dek",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "yanvar",
    "fevral",
    "mart",
    "aprel",
    "may",
    "iyun",
    "iyul",
    "avqust",
    "sentyabr",
    "oktyabr",
    "noyabr",
    "dekabr",
  ],
  name => "Azerbaijani Azerbaijan Latin",
  native_language => "az\N{U+0259}rbaycan",
  native_name => "az\N{U+0259}rbaycan Az\N{U+0259}rbaycan lat\N{U+0131}n",
  native_script => "lat\N{U+0131}n",
  native_territory => "Az\N{U+0259}rbaycan",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1-ci kv.",
    "2-ci kv.",
    "3-c\N{U+00fc} kv.",
    "4-c\N{U+00fc} kv.",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1-ci kvartal",
    "2-ci kvartal",
    "3-c\N{U+00fc} kvartal",
    "4-c\N{U+00fc} kvartal",
  ],
  quarter_stand_alone_abbreviated => [
    "1-ci kv.",
    "2-ci kv.",
    "3-c\N{U+00fc} kv.",
    "4-c\N{U+00fc} kv.",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1-ci kvartal",
    "2-ci kvartal",
    "3-c\N{U+00fc} kvartal",
    "4-c\N{U+00fc} kvartal",
  ],
  script => "Latin",
  territory => "Azerbaijan",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
