{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E dd-MM",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-one" => "'septimana' W 'de' MMMM",
    "MMMMW-count-other" => "'septimana' W 'de' MMMM",
    MMMMd => "d 'de' MMMM",
    MMMd => "d MMM",
    Md => "dd-MM",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM-y",
    yMEd => "E dd-MM-y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "dd-MM-y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ 'de' y",
    "yw-count-one" => "'septimana' w 'de' Y",
    "yw-count-other" => "'septimana' w 'de' Y",
  },
  code => "ia-001",
  date_format_full => "EEEE 'le' d 'de' MMMM y",
  date_format_long => "d 'de' MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd-MM-y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "lun",
    "mar",
    "mer",
    "jov",
    "ven",
    "sab",
    "dom",
  ],
  day_format_narrow => [
    "l",
    "m",
    "m",
    "j",
    "v",
    "s",
    "d",
  ],
  day_format_wide => [
    "lunedi",
    "martedi",
    "mercuridi",
    "jovedi",
    "venerdi",
    "sabbato",
    "dominica",
  ],
  day_stand_alone_abbreviated => [
    "lun",
    "mar",
    "mer",
    "jov",
    "ven",
    "sab",
    "dom",
  ],
  day_stand_alone_narrow => [
    "l",
    "m",
    "m",
    "j",
    "v",
    "s",
    "d",
  ],
  day_stand_alone_wide => [
    "lunedi",
    "martedi",
    "mercuridi",
    "jovedi",
    "venerdi",
    "sabbato",
    "dominica",
  ],
  era_abbreviated => [
    "a.Chr.",
    "p.Chr.",
  ],
  era_narrow => [
    "a.Chr.",
    "p.Chr.",
  ],
  era_wide => [
    "ante Christo",
    "post Christo",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Interlingua",
  month_format_abbreviated => [
    "jan",
    "feb",
    "mar",
    "apr",
    "mai",
    "jun",
    "jul",
    "aug",
    "sep",
    "oct",
    "nov",
    "dec",
  ],
  month_format_narrow => [
    "j",
    "f",
    "m",
    "a",
    "m",
    "j",
    "j",
    "a",
    "s",
    "o",
    "n",
    "d",
  ],
  month_format_wide => [
    "januario",
    "februario",
    "martio",
    "april",
    "maio",
    "junio",
    "julio",
    "augusto",
    "septembre",
    "octobre",
    "novembre",
    "decembre",
  ],
  month_stand_alone_abbreviated => [
    "jan",
    "feb",
    "mar",
    "apr",
    "mai",
    "jun",
    "jul",
    "aug",
    "sep",
    "oct",
    "nov",
    "dec",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "januario",
    "februario",
    "martio",
    "april",
    "maio",
    "junio",
    "julio",
    "augusto",
    "septembre",
    "octobre",
    "novembre",
    "decembre",
  ],
  name => "Interlingua world",
  native_language => "interlingua",
  native_name => "interlingua Mundo",
  native_script => undef,
  native_territory => "Mundo",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1me trimestre",
    "2nde trimestre",
    "3tie trimestre",
    "4te trimestre",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1me trimestre",
    "2nde trimestre",
    "3tie trimestre",
    "4te trimestre",
  ],
  script => undef,
  territory => "world",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
