{
  am_pm_abbreviated => [
    "a.m.",
    "p.m.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E, h:mm B",
    EBhms => "E, h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E d",
    Ehm => "E, h:mm\N{U+202f}a",
    Ehms => "E, h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "MMM 'de' y G",
    GyMMMEd => "E, d 'de' MMM 'de' y G",
    GyMMMd => "d 'de' MMM 'de' y G",
    GyMd => "d/M/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d 'de' MMM",
    MMMMEd => "E, d 'de' MMMM",
    "MMMMW-count-one" => "W.'\N{U+00aa}' 'semana' 'de' MMMM",
    "MMMMW-count-other" => "W.'\N{U+00aa}' 'semana' 'de' MMMM",
    MMMMd => "d 'de' MMMM",
    MMMd => "d 'de' MMM",
    MMdd => "dd/MM",
    Md => "d/M",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMM => "MM/y",
    yMMM => "MMM 'de' y",
    yMMMEd => "E, d 'de' MMM 'de' y",
    yMMMM => "MMMM 'de' y",
    yMMMd => "d 'de' MMM 'de' y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ 'de' y",
    "yw-count-one" => "w.'\N{U+00aa}' 'semana' 'de' Y",
    "yw-count-other" => "w.'\N{U+00aa}' 'semana' 'de' Y",
  },
  code => "gl-ES",
  date_format_full => "EEEE, d 'de' MMMM 'de' y",
  date_format_long => "d 'de' MMMM 'de' y",
  date_format_medium => "d 'de' MMM 'de' y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "luns",
    "mar.",
    "m\N{U+00e9}r.",
    "xov.",
    "ven.",
    "s\N{U+00e1}b.",
    "dom.",
  ],
  day_format_narrow => [
    "l.",
    "m.",
    "m.",
    "x.",
    "v.",
    "s.",
    "d.",
  ],
  day_format_wide => [
    "luns",
    "martes",
    "m\N{U+00e9}rcores",
    "xoves",
    "venres",
    "s\N{U+00e1}bado",
    "domingo",
  ],
  day_stand_alone_abbreviated => [
    "Luns",
    "Mar.",
    "M\N{U+00e9}r.",
    "Xov.",
    "Ven.",
    "S\N{U+00e1}b.",
    "Dom.",
  ],
  day_stand_alone_narrow => [
    "L",
    "M",
    "M",
    "X",
    "V",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "Luns",
    "Martes",
    "M\N{U+00e9}rcores",
    "Xoves",
    "Venres",
    "S\N{U+00e1}bado",
    "Domingo",
  ],
  era_abbreviated => [
    "a.C.",
    "d.C.",
  ],
  era_narrow => [
    "a.C.",
    "d.C.",
  ],
  era_wide => [
    "antes de Cristo",
    "despois de Cristo",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %d %b %Y %T %Z",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Galician",
  month_format_abbreviated => [
    "xan.",
    "feb.",
    "mar.",
    "abr.",
    "maio",
    "xu\N{U+00f1}o",
    "xul.",
    "ago.",
    "set.",
    "out.",
    "nov.",
    "dec.",
  ],
  month_format_narrow => [
    "x.",
    "f.",
    "m.",
    "a.",
    "m.",
    "x.",
    "x.",
    "a.",
    "s.",
    "o.",
    "n.",
    "d.",
  ],
  month_format_wide => [
    "xaneiro",
    "febreiro",
    "marzo",
    "abril",
    "maio",
    "xu\N{U+00f1}o",
    "xullo",
    "agosto",
    "setembro",
    "outubro",
    "novembro",
    "decembro",
  ],
  month_stand_alone_abbreviated => [
    "Xan.",
    "Feb.",
    "Mar.",
    "Abr.",
    "Maio",
    "Xu\N{U+00f1}o",
    "Xul.",
    "Ago.",
    "Set.",
    "Out.",
    "Nov.",
    "Dec.",
  ],
  month_stand_alone_narrow => [
    "X",
    "F",
    "M",
    "A",
    "M",
    "X",
    "X",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Xaneiro",
    "Febreiro",
    "Marzo",
    "Abril",
    "Maio",
    "Xu\N{U+00f1}o",
    "Xullo",
    "Agosto",
    "Setembro",
    "Outubro",
    "Novembro",
    "Decembro",
  ],
  name => "Galician Spain",
  native_language => "galego",
  native_name => "galego Espa\N{U+00f1}a",
  native_script => undef,
  native_territory => "Espa\N{U+00f1}a",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1.\N{U+00ba} trimestre",
    "2.\N{U+00ba} trimestre",
    "3.\N{U+00ba} trimestre",
    "4.\N{U+00ba} trimestre",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1.\N{U+00ba} trimestre",
    "2.\N{U+00ba} trimestre",
    "3.\N{U+00ba} trimestre",
    "4.\N{U+00ba} trimestre",
  ],
  script => undef,
  territory => "Spain",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
