{
  am_pm_abbreviated => [
    "dop.",
    "odp.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E H:mm",
    EHms => "E H:mm:ss",
    Ed => "E d.",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "LLLL y G",
    GyMMMEd => "E d. M. y G",
    GyMMMMEd => "E d. MMMM y G",
    GyMMMMd => "d. MMMM y G",
    GyMMMd => "d. M. y G",
    GyMd => "d. M. y GGGGG",
    H => "H",
    Hm => "H:mm",
    Hms => "H:mm:ss",
    Hmsv => "H:mm:ss v",
    Hmsvvvv => "H:mm:ss, vvvv",
    Hmv => "H:mm v",
    Hmvvvv => "H:mm, vvvv",
    M => "L",
    MEd => "E d. M.",
    MMM => "LLL",
    MMMEd => "E d. M.",
    MMMMEd => "E d. MMMM",
    "MMMMW-count-few" => "W. 't\N{U+00fd}den' MMMM",
    "MMMMW-count-many" => "W. 't\N{U+00fd}den' MMMM",
    "MMMMW-count-one" => "W. 't\N{U+00fd}den' MMMM",
    "MMMMW-count-other" => "W. 't\N{U+00fd}den' MMMM",
    MMMMd => "d. MMMM",
    MMMd => "d. M.",
    Md => "d. M.",
    d => "d.",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmsvvvv => "h:mm:ss\N{U+202f}a, vvvv",
    hmv => "h:mm\N{U+202f}a v",
    hmvvvv => "h:mm\N{U+202f}a, vvvv",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d. M. y",
    yMMM => "LLLL y",
    yMMMEd => "E d. M. y",
    yMMMM => "LLLL y",
    yMMMMEd => "E d. MMMM y",
    yMMMMd => "d. MMMM y",
    yMMMd => "d. M. y",
    yMd => "d. M. y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-few" => "w. 't\N{U+00fd}den' 'roku' Y",
    "yw-count-many" => "w. 't\N{U+00fd}den' 'roku' Y",
    "yw-count-one" => "w. 't\N{U+00fd}den' 'roku' Y",
    "yw-count-other" => "w. 't\N{U+00fd}den' 'roku' Y",
  },
  code => "cs-CZ",
  date_format_full => "EEEE d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d. M. y",
  date_format_short => "dd.MM.yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "po",
    "\N{U+00fa}t",
    "st",
    "\N{U+010d}t",
    "p\N{U+00e1}",
    "so",
    "ne",
  ],
  day_format_narrow => [
    "P",
    "\N{U+00da}",
    "S",
    "\N{U+010c}",
    "P",
    "S",
    "N",
  ],
  day_format_wide => [
    "pond\N{U+011b}l\N{U+00ed}",
    "\N{U+00fa}ter\N{U+00fd}",
    "st\N{U+0159}eda",
    "\N{U+010d}tvrtek",
    "p\N{U+00e1}tek",
    "sobota",
    "ned\N{U+011b}le",
  ],
  day_stand_alone_abbreviated => [
    "po",
    "\N{U+00fa}t",
    "st",
    "\N{U+010d}t",
    "p\N{U+00e1}",
    "so",
    "ne",
  ],
  day_stand_alone_narrow => [
    "P",
    "\N{U+00da}",
    "S",
    "\N{U+010c}",
    "P",
    "S",
    "N",
  ],
  day_stand_alone_wide => [
    "pond\N{U+011b}l\N{U+00ed}",
    "\N{U+00fa}ter\N{U+00fd}",
    "st\N{U+0159}eda",
    "\N{U+010d}tvrtek",
    "p\N{U+00e1}tek",
    "sobota",
    "ned\N{U+011b}le",
  ],
  era_abbreviated => [
    "p\N{U+0159}. n. l.",
    "n. l.",
  ],
  era_narrow => [
    "p\N{U+0159}.n.l.",
    "n.l.",
  ],
  era_wide => [
    "p\N{U+0159}ed na\N{U+0161}\N{U+00ed}m letopo\N{U+010d}tem",
    "na\N{U+0161}eho letopo\N{U+010d}tu",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a\240%-d.\240%B\240%Y,\240%H:%M:%S\240%Z",
  glibc_date_format => "%-d.%-m.%Y",
  glibc_datetime_format => "%a\240%-d.\240%B\240%Y,\240%H:%M:%S",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Czech",
  month_format_abbreviated => [
    "led",
    "\N{U+00fa}no",
    "b\N{U+0159}e",
    "dub",
    "kv\N{U+011b}",
    "\N{U+010d}vn",
    "\N{U+010d}vc",
    "srp",
    "z\N{U+00e1}\N{U+0159}",
    "\N{U+0159}\N{U+00ed}j",
    "lis",
    "pro",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "ledna",
    "\N{U+00fa}nora",
    "b\N{U+0159}ezna",
    "dubna",
    "kv\N{U+011b}tna",
    "\N{U+010d}ervna",
    "\N{U+010d}ervence",
    "srpna",
    "z\N{U+00e1}\N{U+0159}\N{U+00ed}",
    "\N{U+0159}\N{U+00ed}jna",
    "listopadu",
    "prosince",
  ],
  month_stand_alone_abbreviated => [
    "led",
    "\N{U+00fa}no",
    "b\N{U+0159}e",
    "dub",
    "kv\N{U+011b}",
    "\N{U+010d}vn",
    "\N{U+010d}vc",
    "srp",
    "z\N{U+00e1}\N{U+0159}",
    "\N{U+0159}\N{U+00ed}j",
    "lis",
    "pro",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "leden",
    "\N{U+00fa}nor",
    "b\N{U+0159}ezen",
    "duben",
    "kv\N{U+011b}ten",
    "\N{U+010d}erven",
    "\N{U+010d}ervenec",
    "srpen",
    "z\N{U+00e1}\N{U+0159}\N{U+00ed}",
    "\N{U+0159}\N{U+00ed}jen",
    "listopad",
    "prosinec",
  ],
  name => "Czech Czechia",
  native_language => "\N{U+010d}e\N{U+0161}tina",
  native_name => "\N{U+010d}e\N{U+0161}tina \N{U+010c}esko",
  native_script => undef,
  native_territory => "\N{U+010c}esko",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. \N{U+010d}tvrtlet\N{U+00ed}",
    "2. \N{U+010d}tvrtlet\N{U+00ed}",
    "3. \N{U+010d}tvrtlet\N{U+00ed}",
    "4. \N{U+010d}tvrtlet\N{U+00ed}",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. \N{U+010d}tvrtlet\N{U+00ed}",
    "2. \N{U+010d}tvrtlet\N{U+00ed}",
    "3. \N{U+010d}tvrtlet\N{U+00ed}",
    "4. \N{U+010d}tvrtlet\N{U+00ed}",
  ],
  script => undef,
  territory => "Czechia",
  time_format_full => "H:mm:ss, zzzz",
  time_format_long => "H:mm:ss z",
  time_format_medium => "H:mm:ss",
  time_format_short => "H:mm",
  variant => undef,
  version => 42,
}
