{
  am_pm_abbreviated => [
    "prie\N{U+0161}piet",
    "popiet",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "h:mm B, E",
    EBhms => "h:mm:ss B, E",
    EHm => "HH:mm, E",
    EHms => "HH:mm:ss, E",
    Ed => "d, E",
    Ehm => "hh:mm\N{U+202f}a, E",
    Ehms => "hh:mm:ss\N{U+202f}a, E",
    Gy => "y 'm'. G",
    GyMMM => "y-MM G",
    GyMMMEd => "y-MM-dd G, E",
    GyMMMM => "y 'm'. G, LLLL",
    GyMMMMEd => "y 'm'. G MMMM d 'd'., E",
    GyMMMMd => "y 'm'. G MMMM d 'd'.",
    GyMMMd => "y-MM-dd G",
    GyMd => "y-MM-dd G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss; v",
    Hmv => "HH:mm; v",
    M => "MM",
    MEd => "MM-dd, E",
    MMM => "MM",
    MMMEd => "MM-dd, E",
    MMMM => "LLLL",
    MMMMEd => "MMMM d 'd'., E",
    "MMMMW-count-few" => "MMMM W 'sav'.",
    "MMMMW-count-many" => "MMMM W 'sav'.",
    "MMMMW-count-one" => "MMMM W 'sav'.",
    "MMMMW-count-other" => "MMMM W 'sav'.",
    MMMMd => "MMMM d 'd'.",
    MMMd => "MM-dd",
    MMdd => "MM-dd",
    Md => "MM-d",
    d => "dd",
    h => "hh\N{U+202f}a",
    hm => "hh:mm\N{U+202f}a",
    hms => "hh:mm:ss\N{U+202f}a",
    hmsv => "hh:mm:ss\N{U+202f}a; v",
    hmv => "hh:mm\N{U+202f}a; v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y-MM",
    yMMMEd => "y-MM-dd, E",
    yMMMM => "y 'm'. LLLL",
    yMMMMEd => "y 'm'. MMMM d 'd'., E",
    yMMMMd => "y 'm'. MMMM d 'd'.",
    yMMMd => "y-MM-dd",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-few" => "Y w 'sav'.",
    "yw-count-many" => "Y w 'sav'.",
    "yw-count-one" => "Y w 'sav'.",
    "yw-count-other" => "Y w 'sav'.",
  },
  code => "lt-LT",
  date_format_full => "y 'm'. MMMM d 'd'., EEEE",
  date_format_long => "y 'm'. MMMM d 'd'.",
  date_format_medium => "y-MM-dd",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "pr",
    "an",
    "tr",
    "kt",
    "pn",
    "\N{U+0161}t",
    "sk",
  ],
  day_format_narrow => [
    "P",
    "A",
    "T",
    "K",
    "P",
    "\N{U+0160}",
    "S",
  ],
  day_format_wide => [
    "pirmadienis",
    "antradienis",
    "tre\N{U+010d}iadienis",
    "ketvirtadienis",
    "penktadienis",
    "\N{U+0161}e\N{U+0161}tadienis",
    "sekmadienis",
  ],
  day_stand_alone_abbreviated => [
    "pr",
    "an",
    "tr",
    "kt",
    "pn",
    "\N{U+0161}t",
    "sk",
  ],
  day_stand_alone_narrow => [
    "P",
    "A",
    "T",
    "K",
    "P",
    "\N{U+0160}",
    "S",
  ],
  day_stand_alone_wide => [
    "pirmadienis",
    "antradienis",
    "tre\N{U+010d}iadienis",
    "ketvirtadienis",
    "penktadienis",
    "\N{U+0161}e\N{U+0161}tadienis",
    "sekmadienis",
  ],
  era_abbreviated => [
    "pr. Kr.",
    "po Kr.",
  ],
  era_narrow => [
    "pr. Kr.",
    "po Kr.",
  ],
  era_wide => [
    "prie\N{U+0161} Krist\N{U+0173}",
    "po Kristaus",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%Y m. %B %d d. %T %Z",
  glibc_date_format => "%Y-%m-%d",
  glibc_datetime_format => "%Y m. %B %d d. %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Lithuanian",
  month_format_abbreviated => [
    "saus.",
    "vas.",
    "kov.",
    "bal.",
    "geg.",
    "bir\N{U+017e}.",
    "liep.",
    "rugp.",
    "rugs.",
    "spal.",
    "lapkr.",
    "gruod.",
  ],
  month_format_narrow => [
    "S",
    "V",
    "K",
    "B",
    "G",
    "B",
    "L",
    "R",
    "R",
    "S",
    "L",
    "G",
  ],
  month_format_wide => [
    "sausio",
    "vasario",
    "kovo",
    "baland\N{U+017e}io",
    "gegu\N{U+017e}\N{U+0117}s",
    "bir\N{U+017e}elio",
    "liepos",
    "rugpj\N{U+016b}\N{U+010d}io",
    "rugs\N{U+0117}jo",
    "spalio",
    "lapkri\N{U+010d}io",
    "gruod\N{U+017e}io",
  ],
  month_stand_alone_abbreviated => [
    "saus.",
    "vas.",
    "kov.",
    "bal.",
    "geg.",
    "bir\N{U+017e}.",
    "liep.",
    "rugp.",
    "rugs.",
    "spal.",
    "lapkr.",
    "gruod.",
  ],
  month_stand_alone_narrow => [
    "S",
    "V",
    "K",
    "B",
    "G",
    "B",
    "L",
    "R",
    "R",
    "S",
    "L",
    "G",
  ],
  month_stand_alone_wide => [
    "sausis",
    "vasaris",
    "kovas",
    "balandis",
    "gegu\N{U+017e}\N{U+0117}",
    "bir\N{U+017e}elis",
    "liepa",
    "rugpj\N{U+016b}tis",
    "rugs\N{U+0117}jis",
    "spalis",
    "lapkritis",
    "gruodis",
  ],
  name => "Lithuanian Lithuania",
  native_language => "lietuvi\N{U+0173}",
  native_name => "lietuvi\N{U+0173} Lietuva",
  native_script => undef,
  native_territory => "Lietuva",
  native_variant => undef,
  quarter_format_abbreviated => [
    "I k.",
    "II k.",
    "III k.",
    "IV k.",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "I ketvirtis",
    "II ketvirtis",
    "III ketvirtis",
    "IV ketvirtis",
  ],
  quarter_stand_alone_abbreviated => [
    "I ketv.",
    "II ketv.",
    "III ketv.",
    "IV ketv.",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "I ketvirtis",
    "II ketvirtis",
    "III ketvirtis",
    "IV ketvirtis",
  ],
  script => undef,
  territory => "Lithuania",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
