{
  am_pm_abbreviated => [
    "A.M.",
    "G.M.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "MM",
    MEd => "E dd/MM",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-few" => "'sizhun' W 'miz' MMMM",
    "MMMMW-count-many" => "'sizhun' W 'miz' MMMM",
    "MMMMW-count-one" => "'sizhun' W 'miz' MMMM",
    "MMMMW-count-other" => "'sizhun' W 'miz' MMMM",
    "MMMMW-count-two" => "'sizhun' W 'miz' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "dd/MM",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM/y",
    yMEd => "E dd/MM/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "dd/MM/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-few" => "'sizhun' w Y",
    "yw-count-many" => "'sizhun' w Y",
    "yw-count-one" => "'sizhun' w Y",
    "yw-count-other" => "'sizhun' w Y",
    "yw-count-two" => "'sizhun' w Y",
  },
  code => "br-FR",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Lun",
    "Meu.",
    "Mer.",
    "Yaou",
    "Gwe.",
    "Sad.",
    "Sul",
  ],
  day_format_narrow => [
    "L",
    "Mz",
    "Mc",
    "Y",
    "G",
    "Sa",
    "Su",
  ],
  day_format_wide => [
    "Lun",
    "Meurzh",
    "Merc\N{U+02bc}her",
    "Yaou",
    "Gwener",
    "Sadorn",
    "Sul",
  ],
  day_stand_alone_abbreviated => [
    "Lun",
    "Meu.",
    "Mer.",
    "Yaou",
    "Gwe.",
    "Sad.",
    "Sul",
  ],
  day_stand_alone_narrow => [
    "L",
    "Mz",
    "Mc",
    "Y",
    "G",
    "Sa",
    "Su",
  ],
  day_stand_alone_wide => [
    "Lun",
    "Meurzh",
    "Merc\N{U+02bc}her",
    "Yaou",
    "Gwener",
    "Sadorn",
    "Sul",
  ],
  era_abbreviated => [
    "a-raok J.K.",
    "goude J.K.",
  ],
  era_narrow => [
    "a-raok J.K.",
    "goude J.K.",
  ],
  era_wide => [
    "a-raok Jezuz-Krist",
    "goude Jezuz-Krist",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "D\N{U+02bc}ar %A %d a viz %B %Y %T %Z",
  glibc_date_format => "%d.%m.%Y",
  glibc_datetime_format => "D\N{U+02bc}ar %A %d a viz %B %Y %T",
  glibc_time_12_format => "%Ie%M:%S %p",
  glibc_time_format => "%T",
  language => "Breton",
  month_format_abbreviated => [
    "Gen.",
    "C\N{U+02bc}hwe.",
    "Meur.",
    "Ebr.",
    "Mae",
    "Mezh.",
    "Goue.",
    "Eost",
    "Gwen.",
    "Here",
    "Du",
    "Kzu.",
  ],
  month_format_narrow => [
    "01",
    "02",
    "03",
    "04",
    "05",
    "06",
    "07",
    "08",
    "09",
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Genver",
    "C\N{U+02bc}hwevrer",
    "Meurzh",
    "Ebrel",
    "Mae",
    "Mezheven",
    "Gouere",
    "Eost",
    "Gwengolo",
    "Here",
    "Du",
    "Kerzu",
  ],
  month_stand_alone_abbreviated => [
    "Gen.",
    "C\N{U+02bc}hwe.",
    "Meur.",
    "Ebr.",
    "Mae",
    "Mezh.",
    "Goue.",
    "Eost",
    "Gwen.",
    "Here",
    "Du",
    "Kzu.",
  ],
  month_stand_alone_narrow => [
    "01",
    "02",
    "03",
    "04",
    "05",
    "06",
    "07",
    "08",
    "09",
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Genver",
    "C\N{U+02bc}hwevrer",
    "Meurzh",
    "Ebrel",
    "Mae",
    "Mezheven",
    "Gouere",
    "Eost",
    "Gwengolo",
    "Here",
    "Du",
    "Kerzu",
  ],
  name => "Breton France",
  native_language => "brezhoneg",
  native_name => "brezhoneg Fra\N{U+00f1}s",
  native_script => undef,
  native_territory => "Fra\N{U+00f1}s",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1a\N{U+00f1} trim.",
    "2l trim.",
    "3e trim.",
    "4e trim.",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1a\N{U+00f1} trimiziad",
    "2l trimiziad",
    "3e trimiziad",
    "4e trimiziad",
  ],
  quarter_stand_alone_abbreviated => [
    "1a\N{U+00f1} trim.",
    "2l trim.",
    "3e trim.",
    "4e trim.",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1a\N{U+00f1} trimiziad",
    "2l trimiziad",
    "3e trimiziad",
    "4e trimiziad",
  ],
  script => undef,
  territory => "France",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
