{
  am_pm_abbreviated => [
    "a.m.",
    "p.m.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "G y",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM, y G",
    GyMMMd => "d MMM, y G",
    GyMd => "d/M/y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-other" => "W 'semana' MMMM 'killapa'",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "MM-dd",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "E, dd-MM-y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM, y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "dd-MM-y",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "w 'semana' Y 'watapa'",
  },
  code => "qu-PE",
  date_format_full => "EEEE, d MMMM, y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{0} {1}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Lun",
    "Mar",
    "Mi\N{U+00e9}",
    "Jue",
    "Vie",
    "Sab",
    "Dom",
  ],
  day_format_narrow => [
    "L",
    "M",
    "X",
    "J",
    "V",
    "S",
    "D",
  ],
  day_format_wide => [
    "Lunes",
    "Martes",
    "Mi\N{U+00e9}rcoles",
    "Jueves",
    "Viernes",
    "S\N{U+00e1}bado",
    "Domingo",
  ],
  day_stand_alone_abbreviated => [
    "Lun",
    "Mar",
    "Mi\N{U+00e9}",
    "Jue",
    "Vie",
    "Sab",
    "Dom",
  ],
  day_stand_alone_narrow => [
    "L",
    "M",
    "X",
    "J",
    "V",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "Lunes",
    "Martes",
    "Mi\N{U+00e9}rcoles",
    "Jueves",
    "Viernes",
    "S\N{U+00e1}bado",
    "Domingo",
  ],
  era_abbreviated => [
    "a.d.",
    "d.C.",
  ],
  era_narrow => [
    "a.d.",
    "dC",
  ],
  era_wide => [
    "\N{U+00f1}awpa cristu",
    "chanta cristu",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Quechua",
  month_format_abbreviated => [
    "Ene",
    "Feb",
    "Mar",
    "Abr",
    "May",
    "Jun",
    "Jul",
    "Ago",
    "Set",
    "Oct",
    "Nov",
    "Dic",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Enero",
    "Febrero",
    "Marzo",
    "Abril",
    "Mayo",
    "Junio",
    "Julio",
    "Agosto",
    "Setiembre",
    "Octubre",
    "Noviembre",
    "Diciembre",
  ],
  month_stand_alone_abbreviated => [
    "Ene",
    "Feb",
    "Mar",
    "Abr",
    "May",
    "Jun",
    "Jul",
    "Ago",
    "Set",
    "Oct",
    "Nov",
    "Dic",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Enero",
    "Febrero",
    "Marzo",
    "Abril",
    "Mayo",
    "Junio",
    "Julio",
    "Agosto",
    "Setiembre",
    "Octubre",
    "Noviembre",
    "Diciembre",
  ],
  name => "Quechua Peru",
  native_language => "Runasimi",
  native_name => "Runasimi Per\N{U+00fa}",
  native_script => undef,
  native_territory => "Per\N{U+00fa}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => "Peru",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
