{
  am_pm_abbreviated => [
    "PG",
    "PTG",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d-M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMdd => "dd/MM",
    Md => "d-M",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "M-y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "ms-SG",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/MM/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "Isn",
    "Sel",
    "Rab",
    "Kha",
    "Jum",
    "Sab",
    "Ahd",
  ],
  day_format_narrow => [
    "I",
    "S",
    "R",
    "K",
    "J",
    "S",
    "A",
  ],
  day_format_wide => [
    "Isnin",
    "Selasa",
    "Rabu",
    "Khamis",
    "Jumaat",
    "Sabtu",
    "Ahad",
  ],
  day_stand_alone_abbreviated => [
    "Isn",
    "Sel",
    "Rab",
    "Kha",
    "Jum",
    "Sab",
    "Ahd",
  ],
  day_stand_alone_narrow => [
    "I",
    "S",
    "R",
    "K",
    "J",
    "S",
    "A",
  ],
  day_stand_alone_wide => [
    "Isnin",
    "Selasa",
    "Rabu",
    "Khamis",
    "Jumaat",
    "Sabtu",
    "Ahad",
  ],
  era_abbreviated => [
    "S.M.",
    "TM",
  ],
  era_narrow => [
    "S.M.",
    "TM",
  ],
  era_wide => [
    "S.M.",
    "TM",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Malay",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mac",
    "Apr",
    "Mei",
    "Jun",
    "Jul",
    "Ogo",
    "Sep",
    "Okt",
    "Nov",
    "Dis",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "O",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Januari",
    "Februari",
    "Mac",
    "April",
    "Mei",
    "Jun",
    "Julai",
    "Ogos",
    "September",
    "Oktober",
    "November",
    "Disember",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mac",
    "Apr",
    "Mei",
    "Jun",
    "Jul",
    "Ogo",
    "Sep",
    "Okt",
    "Nov",
    "Dis",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "O",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Januari",
    "Februari",
    "Mac",
    "April",
    "Mei",
    "Jun",
    "Julai",
    "Ogos",
    "September",
    "Oktober",
    "November",
    "Disember",
  ],
  name => "Malay Singapore",
  native_language => "Melayu",
  native_name => "Melayu Singapura",
  native_script => undef,
  native_territory => "Singapura",
  native_variant => undef,
  quarter_format_abbreviated => [
    "S1",
    "S2",
    "S3",
    "S4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Suku pertama",
    "Suku Ke-2",
    "Suku Ke-3",
    "Suku Ke-4",
  ],
  quarter_stand_alone_abbreviated => [
    "S1",
    "S2",
    "S3",
    "S4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Suku pertama",
    "Suku Ke-2",
    "Suku Ke-3",
    "Suku Ke-4",
  ],
  script => undef,
  territory => "Singapore",
  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
  time_format_long => "h:mm:ss\N{U+202f}a z",
  time_format_medium => "h:mm:ss\N{U+202f}a",
  time_format_short => "h:mm\N{U+202f}a",
  variant => undef,
  version => 42,
}
